@@ -14,7 +14,7 @@ from datetime import datetime
 import copy
 # from multiprocessing.pool import ThreadPool
 import concurrent.futures
-from tethysts.utils import result_filters, read_json_zstd, get_nearest_station, get_intersected_stations, spatial_query, get_nearest_from_extent, read_pkl_zstd, public_remote_key, chunk_filters, download_results, make_run_date_key, update_nested, results_concat
+from tethysts.utils import read_json_zstd, spatial_query, get_nearest_from_extent, public_remote_key, chunk_filters, download_results, make_run_date_key, update_nested, results_concat
 from s3tethys import get_object_s3, s3_client, decompress_stream_to_object
 from typing import List, Union
 import tethys_data_models as tdm
@@ -544,6 +544,8 @@ class Tethys(object):
     
             ## Clear xarray cache...because it loves caching everything...
             ## This is to ensure that xarray will open the file rather than opening a cache
+            ## The next xarray version should have this issue fixed:
+            ## https://github.com/pydata/xarray/pull/4879
             xr.backends.file_manager.FILE_CACHE.clear()
     
             ## combine results
